@@ -1,7 +1,7 @@
 import nmap
 import socket
 
-class get_ip_in_network:
+class Network:
 
     def __init__(
         self,
